@@ -26,9 +26,9 @@ class ServiceConnectionState(enum.Enum):
 @dataclass
 class ServiceConnection:
     name: str
-    api_version_specifier: str | None = None
-    service_url: str | None = None
-    service_manager_url: str | None = None
+    api_version_specifier: Optional[str] = None
+    service_url: Optional[str] = None
+    service_manager_url: Optional[str] = None
     http_method: str = "POST"
     raise_error: bool = True
     ignore_service_manager_error: bool = True
@@ -38,15 +38,15 @@ class ServiceConnection:
     remote_name: Optional[str] = None
     remote_api_version: Optional[str] = None
     remote_service_version: Optional[str] = None
-    remote_service_manager: 'ServiceManager' = None
+    remote_service_manager: "ServiceManager" = None
     remote_service: GraphQLRemoteObject = None
 
     @classmethod
     def graphql_exclude_fields(cls) -> List[str]:
         return [
-            'schema',
-            'remote_service',
-            'remote_service_manager',
+            "schema",
+            "remote_service",
+            "remote_service_manager",
         ]
 
     def __post_init__(self):
@@ -54,13 +54,12 @@ class ServiceConnection:
             if hasattr(self.schema, "api_version"):
                 try:
                     schema_api_version = getattr(self.schema, "api_version")
-                    schema_api_version = packaging_version.Version(
-                        schema_api_version
-                    )
+                    schema_api_version = packaging_version.Version(schema_api_version)
                     if not self.api_version_specifier:
-                        self.api_version_specifier = \
-                            f"~={schema_api_version.major}" \
+                        self.api_version_specifier = (
+                            f"~={schema_api_version.major}"
                             f".{schema_api_version.minor}"
+                        )
                 except Exception:
                     logging.warning(
                         f"Could not identify the api_version for the "
@@ -72,24 +71,21 @@ class ServiceConnection:
                 executor=GraphQLRemoteExecutor(
                     name=to_camel_case(self.name, title=True),
                     url=self.service_url,
-                    http_method=self.http_method
+                    http_method=self.http_method,
                 ),
-                api=GraphQLAPI(root=self.schema)
+                api=GraphQLAPI(root=self.schema),
             )
 
-    async def async_connect(
-            self,
-            logs: List = None,
-            timeout: int = 5
-    ) -> bool:
-
+    async def async_connect(self, logs: List = None, timeout: int = 5) -> bool:
         if logs is None:
             logs = []
 
         if not self.service_url:
             self.state = ServiceConnectionState.CONFIG_ERROR
-            logs.append(f"[{datetime.datetime.utcnow()}] ERROR: Missing URL"
-                        f" for service {self.name}")
+            logs.append(
+                f"[{datetime.datetime.utcnow()}] ERROR: Missing URL"
+                f" for service {self.name}"
+            )
 
             if self.raise_error:
                 raise TypeError(f"Missing URL for service {self.name}")
@@ -97,8 +93,10 @@ class ServiceConnection:
 
         if not self.schema:
             self.state = ServiceConnectionState.CONFIG_ERROR
-            logs.append(f"[{datetime.datetime.utcnow()}] ERROR: Missing schema"
-                        f" for service {self.name}")
+            logs.append(
+                f"[{datetime.datetime.utcnow()}] ERROR: Missing schema"
+                f" for service {self.name}"
+            )
 
             if self.raise_error:
                 raise TypeError(f"Missing schema for service {self.name}")
@@ -124,9 +122,9 @@ class ServiceConnection:
                     name=name,
                     url=self.service_manager_url,
                     http_method=self.http_method,
-                    http_timeout=timeout
+                    http_timeout=timeout,
                 ),
-                api=GraphQLAPI(root=ServiceManager)
+                api=GraphQLAPI(root=ServiceManager),
             )
 
             a = datetime.datetime.now()
@@ -135,7 +133,7 @@ class ServiceConnection:
             try:
                 uptime = await self.remote_service_manager.call_async("uptime")
             except Exception as err:
-                msg = '' if self.ignore_service_manager_error else 'ERROR: '
+                msg = "" if self.ignore_service_manager_error else "ERROR: "
                 logs.append(
                     f"[{datetime.datetime.utcnow()}] {msg}unable to connect "
                     f"to {name} service manager, timed out after "
@@ -156,22 +154,24 @@ class ServiceConnection:
             if not service_manager_error:
                 b = datetime.datetime.now()
 
-                self.remote_name = await self.remote_service_manager \
-                    .call_async("name")
-                self.remote_api_version = await \
-                    self.remote_service_manager.call_async("api_version")
-                self.remote_service_version = await \
-                    self.remote_service_manager.call_async("service_version")
+                self.remote_name = await self.remote_service_manager.call_async("name")
+                self.remote_api_version = await self.remote_service_manager.call_async(
+                    "api_version"
+                )
+                self.remote_service_version = (
+                    await self.remote_service_manager.call_async("service_version")
+                )
 
                 delta = b - a
-                logs.append(f"[{datetime.datetime.utcnow()}] {name} "
-                            f"Response time {delta} Uptime {uptime}")
+                logs.append(
+                    f"[{datetime.datetime.utcnow()}] {name} "
+                    f"Response time {delta} Uptime {uptime}"
+                )
 
                 if self.api_version_specifier:
                     try:
                         specifier = specifiers.SpecifierSet(
-                            self.api_version_specifier,
-                            prereleases=True
+                            self.api_version_specifier, prereleases=True
                         )
                     except specifiers.InvalidSpecifier as err:
                         logs.append(
@@ -199,13 +199,10 @@ class ServiceConnection:
                             raise err
                         return False
 
-                    if not specifier.contains(
-                            service_version,
-                            prereleases=True
-                    ):
+                    if not specifier.contains(service_version, prereleases=True):
                         logs.append(
                             f"[{datetime.datetime.utcnow()}] ERROR: "
-                            f"api_version mismatch, found "
+                            f"{name} api_version mismatch, found "
                             f"{self.remote_api_version}, required "
                             f"{self.api_version_specifier}"
                         )
@@ -232,8 +229,9 @@ class ServiceConnection:
             name=name,
             url=self.service_url,
             http_method=self.http_method,
-            http_timeout=timeout
+            http_timeout=timeout,
         )
+        response = None
 
         try:
             response = await executor.execute_async("query { __typename }")
@@ -251,14 +249,14 @@ class ServiceConnection:
                 logs.append(
                     f"[{datetime.datetime.utcnow()}] ERROR: {name} API "
                     f"Response error from {self.service_url}. "
-                    f"{response.errors}"
+                    f"{response}"
                 )
                 self.state = ServiceConnectionState.CONNECTION_ERROR
                 if self.raise_error:
                     raise ConnectionError(
                         f"[{datetime.datetime.utcnow()}] ERROR: {name} API "
                         f"Response error from {self.service_url}. "
-                        f"{response.errors}"
+                        f"{response}"
                     )
                 return False
 
@@ -277,14 +275,14 @@ class ServiceManager:
     """
 
     def __init__(
-            self,
-            name: str,
-            schema: Any = None,
-            api_version: str = None,
-            service_version: str = None,
-            connections: List[ServiceConnection] = None,
-            connect_on_init: bool = True,
-            connect_timeout: int = 5
+        self,
+        name: str,
+        schema: Any = None,
+        api_version: str = None,
+        service_version: str = None,
+        connections: List[ServiceConnection] = None,
+        connect_on_init: bool = True,
+        connect_timeout: int = 5,
     ):
         if not connections:
             connections = []
@@ -325,9 +323,8 @@ class ServiceManager:
         self._has_checked_connections = False
         self._logs = []
 
-        fp = os.path.dirname(
-            os.path.realpath(__file__)) + '/service_manager_default.graphql'
-        with open(fp, 'r') as default_query:
+        fp = os.path.dirname(os.path.realpath(__file__)) + "/query.graphql"
+        with open(fp, "r") as default_query:
             default_query = default_query.read()
 
         self.manager_http_server = GraphQLHTTPServer.from_api(
@@ -335,7 +332,7 @@ class ServiceManager:
             serve_graphiql=True,
             allow_cors=True,
             root_value=self,
-            graphiql_default_query=default_query
+            graphiql_default_query=default_query,
         )
 
         if self.connect_on_init:
@@ -352,10 +349,7 @@ class ServiceManager:
                 dependencies = []
                 for service in self._connections:
                     dependencies.append(
-                        service.async_connect(
-                            logs=self._logs,
-                            timeout=_timeout
-                        )
+                        service.async_connect(logs=self._logs, timeout=_timeout)
                     )
                 await asyncio.gather(*dependencies)
 
@@ -373,8 +367,7 @@ class ServiceManager:
         if self._connections:
             for service in self._connections:
                 if service.name == service_name:
-                    if service.state == \
-                            ServiceConnectionState.CONNECTION_ERROR:
+                    if service.state == ServiceConnectionState.CONNECTION_ERROR:
                         try:
                             loop = asyncio.get_running_loop()
                         except RuntimeError:
@@ -397,7 +390,7 @@ class ServiceManager:
         return self._name
 
     @field
-    def api_version(self) -> str:
+    def api_version(self) -> Optional[str]:
         return self._api_version
 
     @field
@@ -406,7 +399,7 @@ class ServiceManager:
 
     @field
     def started_at(self) -> str:
-        return self._started_at.strftime('%Y-%m-%d %H:%M:%S')
+        return self._started_at.strftime("%Y-%m-%d %H:%M:%S")
 
     @field
     def uptime(self) -> str:
@@ -421,6 +414,20 @@ class ServiceManager:
         """
         return self._connections or []
 
+    @field
+    def packages(self) -> List[str]:
+        """
+        All the Packages this service is dependent on.
+        :return:
+        """
+        import pkg_resources
+
+        installed_packages = pkg_resources.working_set
+        installed_packages_list = sorted(
+            ["%s==%s" % (i.key, i.version) for i in installed_packages]
+        )
+        return installed_packages_list
+
     @field
     def logs(self) -> List[str]:
         return self._logs
