@@ -8,14 +8,13 @@ from graphql_service_framework.service import WSGIFramework
 
 
 class ServiceMeshMiddleware:
-
     def __init__(
-            self,
-            wsgi_app: WSGIFramework,
-            service_manager: 'ServiceManager',
-            service_manager_path: str = None,
-            check_connections_on_first_request: bool = True,
-            context_key: str = "services"
+        self,
+        wsgi_app: WSGIFramework,
+        service_manager: "ServiceManager",
+        service_manager_path: str = None,
+        check_connections_on_first_request: bool = True,
+        context_key: str = "services",
     ):
         self.wsgi_app = wsgi_app
         self.service_manager = service_manager
@@ -23,11 +22,7 @@ class ServiceMeshMiddleware:
         self.connect_on_first_request = check_connections_on_first_request
         self.context_key = context_key
 
-    def __call__(
-            self,
-            environ: Dict,
-            start_response: Callable
-    ) -> Iterable[bytes]:
+    def __call__(self, environ: Dict, start_response: Callable) -> Iterable[bytes]:
         if self.connect_on_first_request:
             self.service_manager.connect()
 
