@@ -14,7 +14,7 @@ from graphql_api.api import GraphQLRootTypeDelegate
 from graphql_api import GraphQLAPI
 from graphql_api.remote import GraphQLRemoteExecutor, GraphQLRemoteObject
 
-TClient = TypeVar("TClient", bound='Schema')
+TClient = TypeVar("TClient", bound="Schema")
 
 """
 Schema Provides Utilities to help with a Service
@@ -36,7 +36,6 @@ Schema Class Attributes:
 
 
 class APIVersion(type):
-
     @classmethod
     def __prepare__(mcs, name, bases, **kwargs):
         return super().__prepare__(name, bases, **kwargs)
@@ -49,7 +48,7 @@ class APIVersion(type):
             cls.api_version = api_version
         else:
             for base in bases:
-                if hasattr(base, 'api_version') and base.api_version:
+                if hasattr(base, "api_version") and base.api_version:
                     cls.api_version = base.api_version
 
         if not cls.api_version:
@@ -106,7 +105,7 @@ class Schema(GraphQLRootTypeDelegate, metaclass=APIVersion):
                     schema,
                     schema_class,
                     cls.criticality,
-                    cls.ignore_description_changes
+                    cls.ignore_description_changes,
                 )
 
         return schema
@@ -125,8 +124,8 @@ class Schema(GraphQLRootTypeDelegate, metaclass=APIVersion):
                 )
         # noinspection PyTypeChecker
         return GraphQLRemoteObject(
-            executor=GraphQLRemoteExecutor(url),
-            api=GraphQLAPI(root=cls)
+            executor=GraphQLRemoteExecutor(url, name=cls.__name__),
+            api=GraphQLAPI(root=cls),
         )
 
     @classmethod
@@ -140,18 +139,15 @@ class Schema(GraphQLRootTypeDelegate, metaclass=APIVersion):
 
 
 def validate(
-        graphql_schema: GraphQLSchema,
-        service_schema: Type[Schema],
-        criticality: CriticalityLevel,
-        ignore_description_changes: bool = True
+    graphql_schema: GraphQLSchema,
+    service_schema: Type[Schema],
+    criticality: CriticalityLevel,
+    ignore_description_changes: bool = True,
 ):
-    generated_service_schema = \
-        GraphQLAPI(root=service_schema).graphql_schema()[0]
+    generated_service_schema = GraphQLAPI(root=service_schema).graphql_schema()[0]
 
     if not generated_service_schema:
-        raise ValueError(
-            f"Could not generate service schema for {service_schema}"
-        )
+        raise ValueError(f"Could not generate service schema for {service_schema}")
     query_a = generated_service_schema.query_type
     query_b = graphql_schema.query_type
 
@@ -164,9 +160,7 @@ def validate(
     if mutation_a and mutation_b and mutation_a.name != mutation_b.name:
         mutation_a.name = mutation_b.name
 
-    generated_service_schema_language = print_schema(
-        generated_service_schema
-    )
+    generated_service_schema_language = print_schema(generated_service_schema)
 
     schema_language = print_schema(graphql_schema)
 
@@ -176,26 +170,24 @@ def validate(
     # Ignore description changes as often they are uncontrollable
     if ignore_description_changes:
         changes = [
-            change for change in changes
+            change
+            for change in changes
             if "DescriptionChanged" not in type(change).__name__
         ]
 
     if changes:
-
         raise_error_map = {
             None: [],
             CriticalityLevel.NonBreaking: [
                 CriticalityLevel.NonBreaking,
                 CriticalityLevel.Dangerous,
-                CriticalityLevel.Breaking
+                CriticalityLevel.Breaking,
             ],
             CriticalityLevel.Dangerous: [
                 CriticalityLevel.Dangerous,
-                CriticalityLevel.Breaking
+                CriticalityLevel.Breaking,
             ],
-            CriticalityLevel.Breaking: [
-                CriticalityLevel.Breaking
-            ]
+            CriticalityLevel.Breaking: [CriticalityLevel.Breaking],
         }
 
         raise_err = any(
