@@ -16,35 +16,29 @@ from tests.utils import available
 
 # noinspection DuplicatedCode
 class TestSchema:
-
     def test_schema_validation(self):
         from graphql_api import GraphQLAPI
 
         class UTCTime(Schema):
-
             @field
             def now(self) -> Optional[str]:
                 raise NotImplementedError()
 
         class UTCTimeService(UTCTime):
-
             @field
             def now(self) -> Optional[str]:
                 return str(datetime.datetime.now())
 
-        server = GraphQLHTTPServer.from_api(
-            api=GraphQLAPI(root=UTCTimeService)
-        )
+        server = GraphQLHTTPServer.from_api(api=GraphQLAPI(root=UTCTimeService))
 
         client = Client(server.app())
 
-        response = client.get('/?query={now}')
+        response = client.get("/?query={now}")
 
         assert response.status_code == 200
         assert "now" in response.text
 
         class InvalidUTCTimeService(UTCTime):
-
             @field
             def now(self) -> str:
                 return str(datetime.datetime.now())
@@ -67,29 +61,24 @@ class TestSchema:
         from graphql_api import GraphQLAPI
 
         class UTCTime(Schema):
-
             @field
             def now(self) -> Optional[str]:
                 raise NotImplementedError()
 
         class UTCTimeService(UTCTime):
-
             def now(self) -> Optional[str]:
                 return str(datetime.datetime.now())
 
-        server = GraphQLHTTPServer.from_api(
-            api=GraphQLAPI(root=UTCTimeService)
-        )
+        server = GraphQLHTTPServer.from_api(api=GraphQLAPI(root=UTCTimeService))
 
         client = Client(server.app())
 
-        response = client.get('/?query={now}')
+        response = client.get("/?query={now}")
 
         assert response.status_code == 200
         assert "now" in response.text
 
         class InvalidUTCTimeService(UTCTime):
-
             def now(self) -> str:
                 return str(datetime.datetime.now())
 
@@ -109,13 +98,11 @@ class TestSchema:
 
     def test_schema_client(self):
         class UTCTime(Schema):
-
             @field
             def now(self) -> Optional[str]:
                 raise NotImplementedError()
 
         class UTCTimeService(UTCTime):
-
             @field
             def now(self) -> Optional[str]:
                 return str(datetime.datetime.now())
@@ -130,32 +117,28 @@ class TestSchema:
         local_client = UTCTimeService()
         assert local_client.now()
 
-    def test_create_app(self):
+    def test_create_service(self):
         class UTCTime(Schema):
-
             @field
             def now(self) -> Optional[str]:
                 raise NotImplementedError()
 
         class UTCTimeService(UTCTime):
-
             @field
             def now(self) -> Optional[str]:
                 return str(datetime.datetime.now())
 
-        app = UTCTimeService(config={"test": "test"}).create_service()
+        service = UTCTimeService(config={"test": "test"}).create_service()
 
-        assert app
+        assert service
 
-    def test_create_app_init(self):
+    def test_create_service_init(self):
         class UTCTime(Schema):
-
             @field
             def now(self) -> Optional[str]:
                 raise NotImplementedError()
 
         class UTCTimeService(UTCTime):
-
             def __init__(self, offset: int, config: Dict = None):
                 super().__init__(config=config)
                 self.offset = offset
@@ -163,59 +146,56 @@ class TestSchema:
             @field
             def now(self) -> Optional[str]:
                 return str(
-                    datetime.datetime.now() +
-                    datetime.timedelta(seconds=self.offset)
+                    datetime.datetime.now() + datetime.timedelta(seconds=self.offset)
                 )
 
-        app = UTCTimeService(
-            offset=1, config={"test": "test"}
-        ).create_service()
+        service = UTCTimeService(offset=1, config={"test": "test"}).create_service()
 
-        client = app.client()
+        client = service.client()
 
-        response = client.get('?query={now}')
+        response = client.get("?query={now}")
 
         assert response.status_code == 200 and "now" in response.text
 
-    utc_time_api_url = "https://europe-west2-parob-297412.cloudfunctions." \
-                       "net/utc_time"
+    utc_time_api_url = (
+        "https://europe-west2-parob-297412.cloudfunctions." "net/utc_time"
+    )
 
     # noinspection DuplicatedCode,PyUnusedLocal
     @pytest.mark.skipif(
         not available(utc_time_api_url),
-        reason=f"The UTCTime API '{utc_time_api_url}' is unavailable"
+        reason=f"The UTCTime API '{utc_time_api_url}' is unavailable",
     )
-    def test_create_app_mesh(self):
+    def test_create_service_mesh(self):
         class UTCTime(Schema):
-
             @field
             def now(self) -> Optional[str]:
                 raise NotImplementedError()
 
         class TimeOffset(Schema):
-
             @field
             def now(self, offset: int) -> Optional[str]:
                 raise NotImplementedError()
 
         class TimeOffsetService(TimeOffset):
-
             @field
             def now(self, offset: int) -> Optional[str]:
                 utc_time: UTCTime = ctx.services.utc_time
                 now = datetime.datetime.fromisoformat(utc_time.now())
                 return str(now + datetime.timedelta(seconds=offset))
 
-        app = TimeOffsetService(config={
-            "services": {
-                "utc_time": UTCTime(
-                    url="https://europe-west2-parob-297412.cloudfunctions.net/"
+        service = TimeOffsetService(
+            config={
+                "services": {
+                    "utc_time": UTCTime(
+                        url="https://europe-west2-parob-297412.cloudfunctions.net/"
                         "utc_time"
-                )
+                    )
+                }
             }
-        }).create_service()
+        ).create_service()
 
-        client = app.client()
+        client = service.client()
 
-        response = client.get('?query={now(offset:7200)}')
+        response = client.get("?query={now(offset:7200)}")
         assert response
