@@ -9,11 +9,10 @@ def available(url, method="GET"):
             timeout=5,
             verify=False,
             headers={
-                "accept":
-                    "text/html,application/xhtml+xml,application/xml;q=0.9,"
-                    "image/avif,image/webp,image/apng,*/*;q=0.8,"
-                    "application/signed-exchange;v=b3;q=0.7"
-            }
+                "accept": "text/html,application/xhtml+xml,application/xml;q=0.9,"
+                "image/avif,image/webp,image/apng,*/*;q=0.8,"
+                "application/signed-exchange;v=b3;q=0.7"
+            },
         )
     except (ConnectionError, ConnectTimeout, ReadTimeout):
         return False
